macro_rules! dc_motor {
() => { ... };
}Expand description
The DcMotor provides a uniform interface for using regular DC motors with no fancy controls or feedback. This includes LEGO MINDSTORMS RCX motors and LEGO Power Functions motors.
macro_rules! dc_motor {
() => { ... };
}The DcMotor provides a uniform interface for using regular DC motors with no fancy controls or feedback. This includes LEGO MINDSTORMS RCX motors and LEGO Power Functions motors.