Struct ev3dev_lang_rust::sensors::TouchSensor[][src]

pub struct TouchSensor { /* fields omitted */ }

Touch Sensor

Implementations

impl TouchSensor[src]

pub fn get(port: SensorPort) -> Ev3Result<Self>[src]

Try to get a Self on the given port. Returns None if port is not used or another device is connected.

pub fn find() -> Ev3Result<Self>[src]

Try to find a Self. Only returns a motor if their is exactly one connected, Error::NotFound otherwise.

pub fn list() -> Ev3Result<Vec<Self>>[src]

Extract list of connected 'Self'

pub const MODE_TOUCH: &'static str[src]

Button state

pub fn get_pressed_state(&self) -> Ev3Result<bool>[src]

A boolean indicating whether the current touch sensor is being pressed.