[−][src]Function ev3dev_lang_rust::sound::set_volume
pub fn set_volume(volume: i32) -> Ev3Result<()>
Sets the sound volume to the given percentage [0-100] by calling
amixer -q set <channel> <pct>%.
It tries to determine the default channel
by running amixer scontrols. If that fails as well, it uses the
Playback channel, as that is the only channel on the EV3.