Struct ev3dev_lang_rust::sensors::CompassSensor [−][src]
HiTechnic EV3 / NXT Compass Sensor.
Implementations
impl CompassSensor[src]
pub fn get(port: SensorPort) -> Ev3Result<Self>[src]
Try to get a Self on the given port. Returns None if port is not used or another device is connected.
pub fn find() -> Ev3Result<Self>[src]
Try to find a Self. Only returns a motor if their is exactly one connected, Error::NotFound otherwise.
pub fn list() -> Ev3Result<Vec<Self>>[src]
Extract list of connected 'Self'
pub const COMMAND_START_CALIBRATION: &'static str[src]
Command for starting the calibration
pub const COMMAND_STOP_CALIBRATION: &'static str[src]
Command for stopping the calibration
pub fn get_rotation(&self) -> Ev3Result<i32>[src]
gets rotation (in degree) from the compass sensor
pub fn set_zero(&mut self) -> Ev3Result<()>[src]
sets the origin
pub fn get_relative_rotation(&self) -> Ev3Result<i32>[src]
calculates the rotation to the origin / the zero point
pub fn start_calibration(&self) -> Ev3Result<()>[src]
calibration: start the calibration by start_calibration() turn the robot 360 degrees end the calibration by stop_calibration() attention: if calibration has not finished, the get_rotation method always returns -258 starts the calibration
pub fn stop_calibration(&self) -> Ev3Result<()>[src]
stops the calibration